@@ -48,8 +48,6 @@ object_name = _('Mailing list')
 object_name_plural = _('Mailing lists')
 long_description = ''
 
-module_search_filter = univention.admin.filter.expression('objectClass', 'univentionMailList'),
-
 options = {
 	'default': univention.admin.option(
 		short_description=short_description,
@@ -133,7 +131,7 @@ class object(univention.admin.handlers.simpleLdap):
 		super(object, self)._ldap_pre_ready()
 		if not self.exists() or self.hasChanged('mailAddress'):
 			try:
-				if self['mailAddress']:
+				if self['mailAddress'] and self['mailAddress'].lower() != self.oldinfo.get('mailAddress', '').lower():
 					self.request_lock('mailPrimaryAddress', self['mailAddress'])
 			except univention.admin.uexceptions.noLock:
 				raise univention.admin.uexceptions.mailAddressUsed(self['mailAddress'])
@@ -145,4 +143,5 @@ class object(univention.admin.handlers.simpleLdap):
 
 
 lookup = object.lookup
+lookup_filter = object.lookup_filter
 identify = object.identify
